@@ -1,3 +1,4 @@
+use bevy::prelude::Component;
 use std::fmt::Debug;
 use std::hash::Hash;
 #[cfg(feature = "2D")]
@@ -18,7 +19,7 @@ mod neumann_3d_cell;
 
 /// Trait defining a Cell, every cell type (2d, 3d, hexagonal, etc) must implement this trait
 /// and define an associated `Coordinates` type
-pub trait Cell: Debug + Clone {
+pub trait Cell: Debug + Clone + Component {
     /// Associated coordinates type
     type Coordinates: Clone + Debug + Default + Send + Sync + Eq + Hash;
 
