@@ -1,11 +1,10 @@
 use crate::components::CellState;
+use bevy::prelude::Component;
 #[cfg(feature = "auto-coloring")]
-use crate::ColorResponse;
-#[cfg(feature = "auto-coloring")]
-use bevy::prelude::Color;
+use bevy::render::color::Color;
 use std::fmt::Debug;
 
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Debug, Clone, PartialEq, Component)]
 /// Classic cellular automation state and rules following Conway's game of life variation: The immigration game.
 ///
 /// - Any live cell with fewer than two live neighbours dies, as if by underpopulation.
@@ -46,22 +45,17 @@ impl CellState for RainbowCellState {
     }
 
     #[cfg(feature = "auto-coloring")]
-    fn color_or_material_index(&self) -> ColorResponse {
+    fn color(&self) -> Option<Color> {
         match self {
-            Self::Dead => ColorResponse::None,
-            Self::Alive(v) => ColorResponse::Color(Color::rgb(*v, *v, *v)),
+            Self::Dead => None,
+            Self::Alive(v) => Some(Color::rgb(*v, *v, *v)),
         }
     }
-
-    #[cfg(feature = "auto-coloring")]
-    fn colors() -> &'static [Color] {
-        &[]
-    }
 }
 
 impl RainbowCellState {
     /// Is the cell considered alive
-    pub fn is_alive(&self) -> bool {
+    pub const fn is_alive(&self) -> bool {
         matches!(self, Self::Alive(_))
     }
 }
